==> haskell-interpolate-0.2.0-65-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-interpolate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: interpolate
version: 0.2.0
id: interpolate-0.2.0-5E9nz4olbR4IbkPhc8wueX
key: interpolate-0.2.0-5E9nz4olbR4IbkPhc8wueX
license: MIT
copyright: (c) 2013-2015 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: https://github.com/sol/interpolate#readme
synopsis: String interpolation done right
description:
    String interpolation done right
category: Data, Text
abi: 5415194c6d17592e701fd8f7f45c834e
exposed: True
exposed-modules:
    Data.String.Interpolate Data.String.Interpolate.IsString
    Data.String.Interpolate.Util
hidden-modules: Data.String.Interpolate.Compat
                Data.String.Interpolate.Internal.Util Data.String.Interpolate.Parse
                Paths_interpolate
import-dirs: /usr/lib/ghc-8.6.4/site-local/interpolate-0.2.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/interpolate-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/interpolate-0.2.0
hs-libraries: HSinterpolate-0.2.0-5E9nz4olbR4IbkPhc8wueX
depends:
    base-4.12.0.0 haskell-src-meta-0.8.2-INJHEC4oQl0L8dztRsQnMu
    template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-interpolate/html/interpolate.haddock
haddock-html: /usr/share/doc/haskell-interpolate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-interpolate-0.2.0-68-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-interpolate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: interpolate
version: 0.2.0
id: interpolate-0.2.0-3wKEKdeHtTJ4nZIFBSi7VI
key: interpolate-0.2.0-3wKEKdeHtTJ4nZIFBSi7VI
license: MIT
copyright: (c) 2013-2015 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: https://github.com/sol/interpolate#readme
synopsis: String interpolation done right
description:
    String interpolation done right
category: Data, Text
abi: 2cbb61c6c1d7ae0cf3c64c8a3b63ed84
exposed: True
exposed-modules:
    Data.String.Interpolate Data.String.Interpolate.IsString
    Data.String.Interpolate.Util
hidden-modules: Data.String.Interpolate.Compat
                Data.String.Interpolate.Internal.Util Data.String.Interpolate.Parse
                Paths_interpolate
import-dirs: /usr/lib/ghc-8.6.4/site-local/interpolate-0.2.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/interpolate-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/interpolate-0.2.0
hs-libraries: HSinterpolate-0.2.0-3wKEKdeHtTJ4nZIFBSi7VI
depends:
    base-4.12.0.0 haskell-src-meta-0.8.2-FDpMRx1FcXa5zE4mFJzom5
    template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-interpolate/html/interpolate.haddock
haddock-html: /usr/share/doc/haskell-interpolate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
